{ Unit: BcCheckBox
  ===========================================================================

  The contents of this file are subject to the Bluecave Limited License V 1.0
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001-2002 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001-2002 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Multiline checkbox caption. 

  History:

    2001-11-28: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcCheckBox;

interface

uses Messages, Windows, Graphics, Classes, Controls, StdCtrls;

const
  DefaultWordWrap = False;
  DefaultTransparent = False;

type
  TBcCheckBox = class(TCheckBox)
  private
    FCanvas: TCanvas;
    FWordWrap: Boolean;
    procedure SetWordWrap(const Value: Boolean);
//    function GetTransparent: Boolean;
//    procedure SetTransparent(const Value: Boolean);
    function GetColor: TColor;
    procedure SetColor(const Value: TColor);
  protected
    procedure CreateParams(var Params: TCreateParams); override;
    procedure WMEraseBkgnd(var Message: TWMEraseBkgnd); message WM_ERASEBKGND;
//    procedure WMPaint(var Message: TWMPaint); message WM_PAINT;
    property Canvas: TCanvas read FCanvas;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property Color: TColor read GetColor write SetColor;
    property WordWrap: Boolean read FWordWrap write SetWordWrap default DefaultWordWrap;
//    property Transparent: Boolean read GetTransparent write SetTransparent default DefaultTransparent;
  end;

implementation

uses SysUtils, BcCompsUtilities;

{ TBcCheckBox }

constructor TBcCheckBox.Create(AOwner: TComponent);
begin
  FCanvas := TCanvas.Create;
  FWordWrap := DefaultWordWrap;
  inherited Create(AOwner);
end;

procedure TBcCheckBox.CreateParams(var Params: TCreateParams);
begin
  inherited CreateParams(Params);
  with Params do
  begin
    if FWordWrap then
      Style := Style or BS_MULTILINE or BS_VCENTER;
//    WindowClass.style := WindowClass.style or CS_PARENTDC or CS_VREDRAW	or CS_HREDRAW;
    WindowClass.hbrBackground := 0;
  end;
end;

destructor TBcCheckBox.Destroy;
begin
  FCanvas.Handle := 0;
  FreeAndNil(FCanvas);
  inherited Destroy;
end;

function TBcCheckBox.GetColor: TColor;
begin
  Result := inherited Color;
end;

{function TBcCheckBox.GetTransparent: Boolean;
begin
  Result := not (csOpaque in ControlStyle);
end;}

procedure TBcCheckBox.SetColor(const Value: TColor);
begin
  inherited Color := Value;
end;

{procedure TBcCheckBox.SetTransparent(const Value: Boolean);
begin
  if Transparent <> Value then
  begin
    if Value then
      ControlStyle := ControlStyle - [csOpaque] else
      ControlStyle := ControlStyle + [csOpaque];
    Invalidate;
    RecreateWnd;
  end;
end;}

procedure TBcCheckBox.SetWordWrap(const Value: Boolean);
begin
  if FWordWrap <> Value then
  begin
    FWordWrap := Value;
    RecreateWnd;
  end;
end;

procedure TBcCheckBox.WMEraseBkgnd(var Message: TWMEraseBkgnd);
begin
{  FCanvas.Lock;
  try
    FCanvas.Handle := Message.DC;
    try
      DrawParentImage(Self, FCanvas);
    finally
      FCanvas.Handle := 0;
    end
  finally
    FCanvas.Unlock;
  end;}
  Message.Result := 1;
end;
(*
procedure TBcCheckBox.WMPaint(var Message: TWMPaint);
begin
{  FCanvas.Lock;
  try
    FCanvas.Handle := GetDC(Handle);
    try
      DrawParentImage(Self, FCanvas);
    finally
      ReleaseDC(Handle, FCanvas.Handle);
      FCanvas.Handle := 0;
    end;
  finally
    FCanvas.Unlock;
  end;}
  Message.Result := DefWindowProc(Handle, Message.Msg, Message.DC, Message.Unused);
end;*)

end.
